@@ -61,6 +61,12 @@ def insert_to_db(task_data: dict):
     if task_data["urgency"] == "":
         task_data["urgency"] = 0
 
+    """Workaround until I find a way
+    to espace the quote character.
+    """
+    if "'" in task_data["task"]:
+        task_data["task"] = task_data["task"].replace("'", " ")
+
     query = "INSERT INTO todo (project, task, urgency, due, created_at, updated_at) \
              VALUES ('{0}', '{1}', '{2}', '{3}', '{4}', '{5}')".format(
         task_data["project"],
